/*
** Module   : VT100ProgressKeyboard.java
** Abstract : VT-100 keyboard implementation that has 4GL-specific key remapping
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description---------------------------------
** 001 GES 20150414 First version with core key processing moved from Swing-specific code.
*/

package com.goldencode.p2j.ui.client.chui.driver;

// this usage of AWT events is intentional, they are being used separately from the
// AWT/Swing event model itself; no other AWT/Swing usage is occurring in this class
import java.awt.event.KeyEvent;

import com.goldencode.terminal.*;
import com.goldencode.util.*;

/**
 * VT-100 keyboard implementation with 4GL-specific key remapping.
 */
public class VT100ProgressKeyboard
extends VT100AbstractKeyboard
{  
   /** RETURN key code */
   public static final char RETURN = '\r';

   /** OS platform flag */
   private boolean isWin = false;
   
   /**
    * Constructor.
    */
   public VT100ProgressKeyboard()
   {
      isWin = PlatformHelper.isUnderWindowsFamily();
   }
   
   /**
    * Handle key strokes. VT100AbstractKeyboard class has been designed to emulate a VT100
    * keyboard and some keystrokes are transformed before sending to terminal.
    * <p>
    * Console applications on Windows OS do not use VT100 keyboard codes. In this case we
    * only send the character code, we don't send the key code (the key code is forced to -1).
    * 
    * @param    keyCode
    *           The key code from the input event.
    * @param    charCode
    *           The character code from the input event.
    */
   public void handle(int keyCode, char charCode)
   {
      if (isWin)
      {
         switch (keyCode)
         {
            case KeyEvent.VK_CONTROL:
            case KeyEvent.VK_SHIFT:
            case KeyEvent.VK_ALT:
            case KeyEvent.VK_CAPS_LOCK:    
            case KeyEvent.VK_SCROLL_LOCK:
            case KeyEvent.VK_NUM_LOCK:
            case KeyEvent.VK_PAUSE:
            case KeyEvent.VK_WINDOWS:
            case KeyEvent.VK_CONTEXT_MENU:
               break;
               
            case KeyEvent.VK_BACK_SPACE:
               handleKeystroke(-1, (char) 0x08);
               break;
               
            default:
               handleKeystroke(-1, charCode);
               
               // if a CR was input, we must add the LF
               if (charCode == RETURN)
               {
                  handleKeystroke(-1, '\n');
               }
               break;
         }
      }
      else
      {
         handleKeystroke(keyCode, charCode);                  
      }
   }
   
   /**
    * Handle key inserts.
    * 
    * @param    keyCode
    *           Key code.
    * @param    charCode
    *           Character code
    */
   public void injectKey(int keyCode, char charCode)
   {
      handle(keyCode, charCode);
   }
}
