/*
** Module   : VT100RendererImpl.java
** Abstract : VT100 renderer implementation
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description---------------------------------
** 001 MAG 20140318 First version.
** 002 MAG 20140507 Fix cursor bug for web clients.
** 003 GES 20150414 Reworked to remove Swing-specific implementation details.
*/

package com.goldencode.p2j.ui.client.chui.driver;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.chui.driver.web.*;
import com.goldencode.terminal.*;

/**
 * Implements most behavior for the VT-100 renderer in a UI independent manner.
 */
public abstract class VT100RendererImpl 
extends VT100AbstractRenderer<Cell>
{      
   /**
    * Constructor.
    * 
    * @param    data
    *           Video buffer.
    * @param    rows
    *           Number of rows on the screen.
    * @param    cols
    *           Number of columns on the screen.
    */
   public VT100RendererImpl(Cell[][]data, int rows, int cols)   
   {
      super(data, rows, cols, 0, rows - 1);
   }
   
   /**
    * Get attribute mask.
    * 
    * @param    id
    *           Attribute id.
    * <p>       
    *           0 - NORMAL 
    *           1 - BLINK 
    *           2 - BOLD 
    *           3 - UNDERLINE 
    *           4 - REVERSE
    *           
    * @return   attribute mask.
    */
   @Override
   public int attributeMask(int id)
   {
      switch (id)
      {
         case 0:
            return ColorAttribute.NORMAL.getValue();
         case 1:
            return ColorAttribute.BLINK.getValue();
         case 2:
            return ColorAttribute.BOLD.getValue();
         case 3:
            return ColorAttribute.UNDERLINE.getValue();
         case 4:
            return ColorAttribute.REVERSE.getValue();
         default:
            return ColorAttribute.NORMAL.getValue();
      }      
   }   

   /**
    * Create an empty cell.
    * 
    * @return   An empty video memory cell.
    */
   @Override
   protected Cell emptyCell()
   {
      return Cell.EMPTY_CELL;
   }

   /**
    * Build a video memory cell.
    * 
    * @param    text
    *           Cell character.
    * @param    attribute
    *           Color attributes
    * @param    color
    *           Color pair FG/BG
    *           
    * @return   A new video memory cell.
    */   
   @Override
   protected Cell makeCell(char text, int attribute, int color)
   {
      // box characters are not properly rendered in SWING having BOLD attribute 
      if ((text >= '\u2500') && (text <= '\u25ff'))
      {
         attribute &= 0xFD;
      }
      
      // return a new Cell instance
      return new Cell(text, new Color(attribute, color));
   }
}
