/*
** Module   : GuiColorResolver.java
** Abstract : GUI widget color resolver
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20141022 Created initial version.
** 002 GES 20150425 Removed AWT dependencies and shifted to ColorRgb.
*/

package com.goldencode.p2j.ui.client.gui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.gui.driver.*;

/**
 * Resolve widget color.
 */
public class GuiColorResolver
{
   /** Screen driver. */
   private GuiDriver gd;
   
   /** Widget configuration. */
   private  BaseConfig config;
   
   /** BGCOLOR. */
   public ColorRgb bgColor; 

   /** FGCOLOR. */
   public ColorRgb fgColor; 

   /** Default BGCOLOR. */
   public ColorRgb sysBgColor; 

   /** Default FGCOLOR. */
   public ColorRgb sysFgColor; 

   /** Frame box color. */
   public ColorRgb boxColor; 
      
   /** Title text color. */
   public ColorRgb titleFgColor; 

   /** Title background color. */
   public ColorRgb titleBgColor;

   /** BGCOLOR  selection. */
   public ColorRgb selectionBgColor;
   
   /** FGCOLOR  selection. */
   public ColorRgb selectionFgColor;
   
   /** Thumb button color. */
   public ColorRgb thumbColor;
   
   /** Miscellaneous color. */
   public ColorRgb miscColor;

   /**
    * Constructor.
    * 
    * @param    gd
    *           GUI screen driver.
    * @param    config
    *           Widget configuration.
    * @param    defBgColor
    *           Default system BGCOLOR
    * @param    defFgColor
    *           Default system FGCOLOR
    */
   public GuiColorResolver(GuiDriver gd, BaseConfig config, int defBgColor, int defFgColor)
   {
      this.gd = gd;
      this.config = config;
      
      sysBgColor = gd.getSysColor(defBgColor);
      sysFgColor = gd.getSysColor(defFgColor);
   }
      
   /**
    * Resolve widget FGCOLOR and BGCOLOR.
    */
   public void colors()
   {
      // BGCOLOR
      int bgcolor = config.bgcolor;
      
      if (bgcolor == -1)
      {
         int sysbgcolor = config.sysbgcolor;
         bgColor = (sysbgcolor == -1) ? sysBgColor : gd.getSysColor(sysbgcolor);
      }
      else
      {
         bgColor = gd.getBgColor(bgcolor);
      }
      
      // FGCOLOR
      int fgcolor = config.fgcolor;
      
      if (fgcolor == -1)
      {
         int sysfgcolor = config.sysfgcolor;
         fgColor = (sysfgcolor == -1) ? sysFgColor : gd.getSysColor(sysfgcolor);         
      }
      else
      {
         fgColor = gd.getFgColor(fgcolor);
      }
   }   
}
